import type { IBaseConfig, IHttpServerConfig, IDatabaseConfig } from './base.config.js';
import type { ISmsConfig } from './sms.config.js';

/**
 * Platform service configuration
 * Root configuration that includes all service configurations
 */
export interface IPlatformConfig extends IBaseConfig {
  /**
   * HTTP server configuration
   */
  server?: IHttpServerConfig;
  
  /**
   * Database configuration
   */
  database?: IDatabaseConfig;
  
  /**
   * Email service configuration
   * @deprecated - Use IUnifiedEmailServerOptions in DcRouter instead
   */
  email?: any;
  
  /**
   * SMS service configuration
   */
  sms?: ISmsConfig;
  
  /**
   * Path configuration
   */
  paths?: {
    /**
     * Data directory path
     */
    dataDir?: string;
    
    /**
     * Logs directory path
     */
    logsDir?: string;
    
    /**
     * Temporary directory path
     */
    tempDir?: string;
    
    /**
     * Email templates directory path
     */
    emailTemplatesDir?: string;
  };
}